==> 0.0.10.tar.gz: lib/core/const/string_const.dart <==
const String kDependency = 'Dependency';
const String kErrorChooseDifferentFeatureName =
    'Error: Destination feature directory already exists. Please choose a different feature name';

const String kError = 'Error:';

///Common strings
const String kEnterYourFeatureName = "Enter your feature name: ";
const String kDoesNotExist = "does not exist.";
const String kFeatureLabel = "Feature";

///Command strings
const String kCouldNotFindCommand = "Could not find command.";
const String kAvailableCommands =
    "\n\nAvailable commands:\n1.create feature\n2.create widget\n3.create model\n4.Add get-api-call\n5.Add post-api-call\n\nPlease retry with available command...\n\n";

///Create model
const String kModelSuccessMessage =
    "Dart model class is generated successfully in";
const String kModelErrorMessage =
    "Dart model class is not generated successfully";

///Create feature
const String kFeatureString = 'Feature';
const String kCreated = 'created';
const String kErrorCopyingFolder = 'Error copying folder:';
const String kImport = "import";

///Create widget
const String kCommonOrFeature =
    "Do you want to create a common widget or a feature widget? (common/feature): ";
const String kCommonOrFeatureError =
    'Invalid choice. Please choose "common" or "feature".';
const String kWidgetAlreadyExistError =
    'already exists. Please choose a different name.';
const String kWidgetLabel = 'Widget';
const String kCreatedAt = 'created at';

///Add api call
const String kGet = 'GET';
const String kPost = 'POST';
const String kMultipart = 'MULTIPART';
const String kEnterFeatureName = 'Enter feature name:';
const String kAddShimmerOrNot =
    'Do you want to add shimmer to this API call? (Y/N):';
const String kQueryParametersOrNot =
    'Does this API have request query parameters? (Y/N):';
const String kRequestBodyOrNot = 'Does this API have request body? (Y/N):';
const String kYes = 'y';
const String kRequestJsonFilePath = 'Enter request json file path:';
const String kResponseBodyOrNot = 'Does this API have response body? (Y/N):';
const String kFileAT = 'File at';
const String kExistChooseDifferentUseCase =
    'already exists. Please choose a different usecase name';
const String kNotFoundPubCacheDir = 'not found in .pub-cache directory';
const String kDoesNotContainLibFolder = 'does not contain a lib folder';
const String kFolderNotExist = 'folder does not exist';
const String kResponseJsonFilePath = 'Enter response json file path:';
const String kUseCase = 'Usecase';
const String kUseCaseAddedToInjection =
    'UseCase added to the injection container successfully';
const String kNotExist = 'not exists';
const String kApiCodeUpdate = 'API code has been successfully updated on the';
const String kFile = 'file';
const String kDataSource = 'Data source';
const String kDataSourceImpl = 'Data source impl';
const String kRepo = 'Repo';
const String kRepoImpl = 'Repo impl';
const String kMockRepoImpl = 'Mock Repo impl';
const String kEvent = 'Event';
const String kState = 'State';
const String kBloc = 'Bloc ';
const String kApiConstantUpdate =
    'API string constant added successfully to the api constants file ';
const String kMockApiConstantUpdate =
    'API string constant added successfully to the mock api constants file ';

///Create assets
const String kImageGeneratedSuccessMessage = 'Images generated successfully';
const String kImageDecodingErrorMessage = 'Decoding image';

==> 1.0.0.tar.gz: lib/core/const/string_const.dart <==
const String kPackageName = 'jt_flutter_cli';
const String kDependency = 'Dependency';
const String kErrorChooseDifferentFeatureName =
    'Error: Destination feature directory already exists. Please choose a different feature name';

const String kError = 'Error:';
const String kErrorProcessingFile = 'Error processing file';
const String kErrorReadingPubspec = 'Error reading pubspec.yaml:';
const String kClosingCurlyBracketNotFound = 'Closing curly bracket not found.';
const String kDependencyNotInPubspec = 'is not a dependency in pubspec.yaml.';
const String kPubspecNotFound = 'pubspec.yaml file not found.';

///Common strings
const String kEnterYourFeatureName = "Enter your feature name: ";
const String kDoesNotExist = "does not exist.";
const String kFeatureLabel = "Feature";
const String kDependencies = "dependencies";

///Command strings
const String kCouldNotFindCommand = "Could not find command.";
const String kAvailableCommands =
    "\n\nAvailable commands:\n1.create feature\n2.create widget\n3.create model\n4.Add get-api-call\n5.Add post-api-call\n\nPlease retry with available command...\n\n";

///Create model
const String kModelSuccessMessage =
    "Dart model class is generated successfully in";
const String kModelErrorMessage =
    "Dart model class is not generated successfully";

///Create feature
const String kFeatureString = 'feature';
const String kCreated = 'created';
const String kErrorCopyingFolder = 'Error copying folder:';
const String kImport = "import";

///Create widget
const String kCommonOrFeature =
    "Do you want to create a common widget or a feature widget? (common/feature): ";
const String kCommonOrFeatureError =
    'Invalid choice. Please choose "common" or "feature".';
const String kWidgetAlreadyExistError =
    'already exists. Please choose a different name.';
const String kWidgetLabel = 'Widget';
const String kCreatedAt = 'created at';

///Add api call
const String kGet = 'GET';
const String kPost = 'POST';
const String kMultipart = 'MULTIPART';
const String kEnterFeatureName = 'Enter feature name:';
const String kAddShimmerOrNot =
    'Do you want to add shimmer to this API call? (Y/N):';
const String kQueryParametersOrNot =
    'Does this API have request query parameters? (Y/N):';
const String kRequestBodyOrNot = 'Does this API have request body? (Y/N):';
const String kYes = 'y';
const String kRequestJsonFilePath = 'Enter request json file path:';
const String kResponseBodyOrNot = 'Does this API have response body? (Y/N):';
const String kFileAT = 'File at';
const String kExistChooseDifferentUseCase =
    'already exists. Please choose a different usecase name';
const String kNotFoundPubCacheDir = 'not found in .pub-cache directory';
const String kDoesNotContainLibFolder = 'does not contain a lib folder';
const String kFolderNotExist = 'folder does not exist';
const String kResponseJsonFilePath = 'Enter response json file path:';
const String kNotExist = 'not exists';
const String kAddedApiTo = 'Added API to';

///Create assets
const String kImageGeneratedSuccessMessage = 'Images generated successfully';
const String kImageDecodingErrorMessage = 'Decoding image';
